==> haskell-http-client-0.7.17-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client
version:              0.7.17
visibility:           public
id:                   http-client-0.7.17-AUuOyA54dq3IiMr8FLNnqs
key:                  http-client-0.7.17-AUuOyA54dq3IiMr8FLNnqs
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  24976e3297b910ccde06acde383c895e
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-0.7.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-0.7.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-0.7.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client
hs-libraries:         HShttp-client-0.7.17-AUuOyA54dq3IiMr8FLNnqs
depends:
    array-0.5.4.0 async-2.2.5-EyV9emCuOIPGUIakwGPKTd base-4.17.2.1
    base64-bytestring-1.2.1.0-9rjbyifcAWs81fTufDCHjJ
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-GbIPZPr2YUt5gu3TjAsadi containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm deepseq-1.4.8.0
    exceptions-0.10.5 filepath-1.4.2.2 ghc-prim-0.9.1
    http-types-0.12.4-GwcjbD6je3aL0GKpFarP8k
    iproute-1.7.14-69DWx4NDSHY5IIEQp7TBcR
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    network-3.1.4.0-4LxzNodBXIzL8bUGme1k8m
    network-uri-2.6.4.2-2U8duEjYT0p2SuyLAFgLE2
    random-1.2.1.2-IN7ymD0AKvltzeAmi6gkc stm-2.5.1.0
    streaming-commons-0.2.2.6-LPUPGkna0351Ib2Wvmo9tO text-2.0.2
    time-1.12.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.7.17-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client
version:              0.7.17
visibility:           public
id:                   http-client-0.7.17-4ADmMJlTJbdEGFQAXSREop
key:                  http-client-0.7.17-4ADmMJlTJbdEGFQAXSREop
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  99075b9264e3caeaefe522d93dcfc1b7
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-0.7.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-0.7.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-0.7.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client
hs-libraries:         HShttp-client-0.7.17-4ADmMJlTJbdEGFQAXSREop
depends:
    array-0.5.4.0 async-2.2.5-EyV9emCuOIPGUIakwGPKTd base-4.17.2.1
    base64-bytestring-1.2.1.0-9rjbyifcAWs81fTufDCHjJ
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-GbIPZPr2YUt5gu3TjAsadi containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm deepseq-1.4.8.0
    exceptions-0.10.5 filepath-1.4.2.2 ghc-prim-0.9.1
    http-types-0.12.4-84PTldXFVlSHvwiFY4h2Wj
    iproute-1.7.14-69DWx4NDSHY5IIEQp7TBcR
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    network-3.1.4.0-4LxzNodBXIzL8bUGme1k8m
    network-uri-2.6.4.2-2U8duEjYT0p2SuyLAFgLE2
    random-1.2.1.2-IN7ymD0AKvltzeAmi6gkc stm-2.5.1.0
    streaming-commons-0.2.2.6-LPUPGkna0351Ib2Wvmo9tO text-2.0.2
    time-1.12.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
